bbprep.generators.TorsionRange
==============================

.. currentmodule:: bbprep.generators

.. autoclass:: TorsionRange
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TorsionRange.smarts
      ~TorsionRange.expected_num_atoms
      ~TorsionRange.scanned_ids
      ~TorsionRange.scanned_range
   
   